==> moengagesdk-3.7.04-sources.jar: com/moengage/core/integrations/segment/TrackSegmentUserAttributeTask.java <==
package com.moengage.core.integrations.segment;

import android.content.Context;
import com.moe.pushlibrary.MoEHelper;
import com.moe.pushlibrary.utils.MoEHelperConstants;
import com.moengage.core.ConfigurationProvider;
import com.moengage.core.Logger;
import com.moengage.core.MoEUtils;
import com.moengage.core.executor.SDKTask;
import com.moengage.core.executor.TaskResult;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * Transform Segment's User Attribute to MoEngage format.
 *
 * @author Umang Chamaria
 * Date: 29/04/19
 */
public class TrackSegmentUserAttributeTask extends SDKTask {

  private Map<String, Object> userAttributesMap;

  private static final String TAG = "TrackSegmentUserAttributeTask";

  public TrackSegmentUserAttributeTask(Context context, Map<String, Object> userAttributesMap) {
    super(context);
    this.userAttributesMap = userAttributesMap;
  }

  @Override public TaskResult execute() {
    try {
      Logger.v(TAG + " execute() : Transforming identifiers to "
          + "MoEngage format.");
      trackSegmentId();
      List<String> removeAttributeList = new ArrayList<>();
      for (Map.Entry<String, Object> entry : userAttributesMap.entrySet()) {
        String attributeName = entry.getKey();
        Object attributeValue = entry.getValue();
        if (attributeValue instanceof String && MoEUtils.isDate((String) attributeValue)) {
          MoEHelper.getInstance(context).setUserAttributeISODate(attributeName,
              attributeValue.toString());
          removeAttributeList.add(attributeName);
        }
      }
      for (String attribute : removeAttributeList) {
        userAttributesMap.remove(attribute);
      }
      MoEHelper.getInstance(context).setUserAttribute(userAttributesMap);
    } catch (Exception e) {
      Logger.f(TAG + " execute() : Exception ", e);
    }
    return null;
  }

  private void trackSegmentId() {
    try {
      if (userAttributesMap.containsKey(MoEHelperConstants.USER_ATTRIBUTE_SEGMENT_ID)){
        String segmentId =
            (String) userAttributesMap.get(MoEHelperConstants.USER_ATTRIBUTE_SEGMENT_ID);
        if (MoEUtils.isEmptyString(segmentId)){
          ConfigurationProvider.getInstance(context).saveSegmentAnonymousId(segmentId);
        }
      }
    } catch (Exception e) {
      Logger.e( TAG + " trackSegmentId() : ", e);
    }
  }

  @Override public String getTaskTag() {
    return TAG_TRACK_USER_ATTRIBUTE_SEGMENT;
  }

  @Override public boolean isSynchronous() {
    return false;
  }
}

==> moengagesdk-4.0.02-sources.jar: com/moengage/core/integrations/segment/TrackSegmentUserAttributeTask.java <==
package com.moengage.core.integrations.segment;

import android.content.Context;
import com.moe.pushlibrary.MoEHelper;
import com.moe.pushlibrary.utils.MoEHelperConstants;
import com.moengage.core.ConfigurationProvider;
import com.moengage.core.Logger;
import com.moengage.core.MoEUtils;
import com.moengage.core.executor.SDKTask;
import com.moengage.core.executor.TaskResult;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * Transform Segment's User Attribute to MoEngage format.
 *
 * @author Umang Chamaria
 * Date: 29/04/19
 */
public class TrackSegmentUserAttributeTask extends SDKTask {

  private Map<String, Object> userAttributesMap;

  private static final String TAG = "TrackSegmentUserAttributeTask";

  public TrackSegmentUserAttributeTask(Context context, Map<String, Object> userAttributesMap) {
    super(context);
    this.userAttributesMap = userAttributesMap;
  }

  @Override public TaskResult execute() {
    try {
      Logger.v(TAG + " execute() : Transforming identifiers to "
          + "MoEngage format.");
      trackSegmentId();
      List<String> removeAttributeList = new ArrayList<>();
      for (Map.Entry<String, Object> entry : userAttributesMap.entrySet()) {
        String attributeName = entry.getKey();
        Object attributeValue = entry.getValue();
        if (attributeValue instanceof String && MoEUtils.isDate((String) attributeValue)) {
          MoEHelper.getInstance(context).setUserAttributeISODate(attributeName,
              attributeValue.toString());
          removeAttributeList.add(attributeName);
        }
      }
      for (String attribute : removeAttributeList) {
        userAttributesMap.remove(attribute);
      }
      MoEHelper.getInstance(context).setUserAttribute(userAttributesMap);
    } catch (Exception e) {
      Logger.f(TAG + " execute() : Exception ", e);
    }
    return null;
  }

  private void trackSegmentId() {
    try {
      if (userAttributesMap.containsKey(MoEHelperConstants.USER_ATTRIBUTE_SEGMENT_ID)){
        String segmentId =
            (String) userAttributesMap.get(MoEHelperConstants.USER_ATTRIBUTE_SEGMENT_ID);
        if (!MoEUtils.isEmptyString(segmentId)){
          ConfigurationProvider.getInstance(context).saveSegmentAnonymousId(segmentId);
        }
      }
    } catch (Exception e) {
      Logger.e( TAG + " trackSegmentId() : ", e);
    }
  }

  @Override public String getTaskTag() {
    return TAG_TRACK_USER_ATTRIBUTE_SEGMENT;
  }

  @Override public boolean isSynchronous() {
    return false;
  }
}
